#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fold-debounce
version:              0.2.0.17
visibility:           public
id:                   fold-debounce-0.2.0.17-FKI5NRjwLn9IB6Ig8g8Op3
key:                  fold-debounce-0.2.0.17-FKI5NRjwLn9IB6Ig8g8Op3
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  400e10c50a9d8e2e967b2c2a5f6fc916
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fold-debounce-0.2.0.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fold-debounce-0.2.0.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fold-debounce-0.2.0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.17-FKI5NRjwLn9IB6Ig8g8Op3
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    stm-2.5.1.0 stm-delay-0.1.1.2-8F8oXPAG2aeLwbAcW5DMme time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

